@@ -3,6 +3,8 @@
 #![warn(clippy::missing_panics_doc)]
 #![warn(clippy::cargo)]
 #![allow(clippy::match_like_matches_macro)]
+#![allow(clippy::needless_late_init)]
+#![allow(clippy::large_enum_variant)]
 
 //! ## Lightweight parsing for Rust proc macros
 //!
@@ -29,10 +31,10 @@
 //! ## Example
 //!
 //! ```rust
-//! use venial::{parse_type, TypeDeclaration};
+//! use venial::{parse_declaration, Declaration};
 //! use quote::quote;
 //!
-//! let enum_type = parse_type(quote!(
+//! let enum_type = parse_declaration(quote!(
 //!     enum Shape {
 //!         Square(Square),
 //!         Circle(Circle),
@@ -41,24 +43,39 @@
 //! ));
 //!
 //! let enum_type = match enum_type {
-//!     TypeDeclaration::Enum(enum_type) => enum_type,
+//!     Declaration::Enum(enum_type) => enum_type,
 //!     _ => unreachable!(),
 //! };
 //!
-//! assert_eq!(enum_type.variants[0].name, "Square");
-//! assert_eq!(enum_type.variants[1].name, "Circle");
-//! assert_eq!(enum_type.variants[2].name, "Triangle");
+//! assert_eq!(enum_type.variants[0].0.name, "Square");
+//! assert_eq!(enum_type.variants[1].0.name, "Circle");
+//! assert_eq!(enum_type.variants[2].0.name, "Triangle");
 //! ```
 
-mod parse;
-mod types;
+// Note: to get rust-analyzer to work within the `fuzz` module, add the following to .cargo/config.toml:
+// [build]
+// rustflags = ["--cfg", "fuzzing"]
+#[cfg(all(test, fuzzing))]
+pub mod fuzz;
 
 #[cfg(test)]
 mod tests;
 
-pub use parse::parse_type;
+mod error;
+mod parse;
+mod parse_expr;
+mod parse_fn;
+mod parse_type;
+mod parse_utils;
+mod punctuated;
+mod types;
+mod types_edition;
 
+pub use error::Error;
+pub use parse::{parse_declaration, parse_expression_list};
+pub use punctuated::Punctuated;
 pub use types::{
-    Attribute, Enum, EnumDiscriminant, EnumVariant, GenericParams, NamedField, Struct,
-    StructFields, TupleField, TyExpr, TypeDeclaration, VisMarker, WhereClauses,
+    Attribute, Declaration, Enum, EnumDiscriminant, EnumVariant, Expression, GenericBound,
+    GenericParam, GenericParamList, NamedField, NamedStructFields, Struct, StructFields,
+    TupleField, TupleStructFields, TyExpr, Union, VisMarker, WhereClause, WhereClauseItem,
 };
